@@ -14,21 +14,34 @@ This file is part of Ojota.
     You should have received a copy of the GNU  Lesser General Public License
     along with Ojota.  If not, see <http://www.gnu.org/licenses/>.
 """
+from json import dumps
+
 import ojota.sources
 
 from ojota.sources import JSONSource
 from ojota.cache import Cache
+from threading import current_thread
 
 
 def current_data_code(data_code):
     """Sets the current data path."""
-    Ojota.CURRENT_DATA_CODE = data_code
+    Ojota._data_codes[current_thread()] = data_code
+
+
+def get_current_data_code():
+    return Ojota._data_codes[current_thread()]
 
 
 def set_data_source(data_path):
     ojota.sources._DATA_SOURCE = data_path
 
 
+def preload(*args):
+    for arg in args:
+        if hasattr(arg, "preload"):
+            arg.preload()
+
+
 class Relation(object):
     """Adds a relation to another object."""
     def __init__(self, attr_fk, to_class, related_name=None):
@@ -141,14 +154,14 @@ class Ojota(object):
     """Base class to create instances of serialized data in the source files.
     """
     __metaclass__ = MetaOjota
-    CURRENT_DATA_CODE = ''
+    _data_codes = {}
     plural_name = None
     data_in_root = True
     pk_field = "pk"
     required_fields = None
     cache = Cache()
     data_source = JSONSource()
-    default_order= None
+    default_order = None
 
     @property
     def primary_key(self):
@@ -181,11 +194,15 @@ class Ojota(object):
             self.fields.append(key)
             setattr(self, key, val)
 
+    @classmethod
+    def get_current_data_code(cls):
+        return get_current_data_code()
+
     @classmethod
     def get_cache_name(cls):
         cache_name = '_cache_' + cls.get_plural_name()
-        if not cls.data_in_root and Ojota.CURRENT_DATA_CODE:
-            cache_name += '_' + Ojota.CURRENT_DATA_CODE
+        if not cls.data_in_root and get_current_data_code():
+            cache_name += '_' + get_current_data_code()
         return cache_name
 
     @classmethod
@@ -379,6 +396,9 @@ class Ojota(object):
     def to_dict(self):
         return dict([(field, getattr(self, field)) for field in self.fields])
 
+    def to_json(self):
+        return dumps(self.to_dict())
+
     def update(self, **kwargs):
         """Updates the given values."""
         for arg, value in kwargs.items():
@@ -429,3 +449,7 @@ class Ojota(object):
                 self.dump_values(new_data)
             else:
                 self.update(**new_data)
+
+    @classmethod
+    def preload(cls):
+        cls.all()
